block: Read only one sector for format probing
authorKevin Wolf <kwolf@redhat.com>
Thu, 20 Nov 2014 15:27:11 +0000 (16:27 +0100)
committerKevin Wolf <kwolf@redhat.com>
Wed, 10 Dec 2014 09:31:12 +0000 (10:31 +0100)
The only image format driver that even potentially accesses anything
after 512 bytes in its bdrv_probe() implementation is VMDK, which reads
a plain-text descriptor file. In practice, the field it's looking for
seems to come first and will be well within the first 512 bytes, too.

Signed-off-by: Kevin Wolf <kwolf@redhat.com>
Reviewed-by: Stefan Hajnoczi <stefanha@redhat.com>
Reviewed-by: Max Reitz <mreitz@redhat.com>
Message-id: 1416497234-29880-7-git-send-email-kwolf@redhat.com
Signed-off-by: Stefan Hajnoczi <stefanha@redhat.com>
Signed-off-by: Kevin Wolf <kwolf@redhat.com>
block.c
include/block/block_int.h

diff --git a/block.c b/block.c
index aa7edf89117b04c3ffaab8204475340c8e5bc11f..809ec5458791aa1ffbed4f233fd8e14fd219b26b 100644 (file)
--- a/block.c
+++ b/block.c
@@ -654,8 +654,8 @@ BlockDriver *bdrv_find_protocol(const char *filename,
  * we do it anyway for backward compatibility.
  *
  * @buf         contains the image's first @buf_size bytes.
* @buf_size    is the buffer size in bytes (generally 2048, but can be smaller
*              if the image file is smaller)
  * @filename    is its filename.
  *
  * For all block drivers, call the bdrv_probe() method to get its
@@ -685,7 +685,7 @@ static int find_image_format(BlockDriverState *bs, const char *filename,
                              BlockDriver **pdrv, Error **errp)
 {
     BlockDriver *drv;
-    uint8_t buf[2048];
+    uint8_t buf[BLOCK_PROBE_BUF_SIZE];
     int ret = 0;
 
     /* Return the raw BlockDriver * to scsi-generic devices or empty drives */
index a1c17b95788f2ea2bde110f9ccba51176753aa1c..cd94559a649883fb85d1a26a553fb0660a945f79 100644 (file)
@@ -57,6 +57,8 @@
 #define BLOCK_OPT_REDUNDANCY        "redundancy"
 #define BLOCK_OPT_NOCOW             "nocow"
 
+#define BLOCK_PROBE_BUF_SIZE        512
+
 typedef struct BdrvTrackedRequest {
     BlockDriverState *bs;
     int64_t offset;
@@ -654,8 +654,8 @@ BlockDriver *bdrv_find_protocol(const char *filename,
  *
  * @buf         contains the image's first @buf_size bytes.
- * @buf_size    is the buffer size in bytes (generally 2048, but can be smaller
- *              if the image file is smaller)
+ * @buf_size    is the buffer size in bytes (generally BLOCK_PROBE_BUF_SIZE,
+ *              but can be smaller if the image file is smaller)
  * @filename    is its filename.
  *